
*** formats used to display age group limits, display negative numbers as positive;
proc format;
value age 
11 = '0-4'     10 = '5-9'      9 = '10-14'    8 = '15-24'
 7 = '25-34'    6 = '35-44'    5 = '45-54'    4 = '55-64'
 3 = '65-74'    2 = '75-84'    1 = '85+'
;
picture posval low-high='000,009';
run;

*** create an annotate data set to place text on population pyramid;
*** add gender and age-grop labels;
data age_labels;
length text $10 style $15;
retain xsys ysys '2' hsys '3' size 3 position '5' x 0 
       function 'label' color 'blue' style "'Helvetica'" when 'a';
do midpoint = 1 to 11;
   text = put(midpoint,age.);
   output;
end;
midpoint=1; ysys='5'; y=100; size=4; style="'HelveticaBold'";
x=-3000; text='FEMALES'  ; position='6'; output;
x= 3000; text='MALES'    ; position='4'; output;
x=0    ; text='AGE GROUP'; position='5'; output;
run; 

*** choose the JAVAMETA device driver;
goptions reset=all device=javameta 
         ftext='Helvetica' htext=3 gunit=pct
         xpixels=800 ypixels=600;

*** use the _WEBOUT filename (the JAVAMETA device driver uses the as a default destination);
filename _webout "z:\pyramid.html";

*** set axis and pattern characteristics;
axis1 style=0 value=none label=none color='blue';
axis2 order=(-3000 to 3000 by 1000) label=('POPULATION (1000s)') color='blue';

pattern1 v=s c=cxbdd7e7;
pattern2 v=s c=cx6baed6;


*** write records to an HTML file - text to precede metagraphics produced by PROC GCHART;
data _null_;
   file _webout;
   input;
   put _infile_;
   datalines;
   <html>
   <head>
   <title>JAVA METAGRAPHICS</title>
   </head>
   <body>
   <APPLET CODE="MetaViewApplet.class" CODEBASE="file:///C:\SAS\Shared Files\applets\9.1"
    ARCHIVE="metafile.zip" Width=800 Height=600>
   <param name="ZoomControlEnabled" value="false">
   <param name="Metacodes"          value="
   ;
run;

*** use a macro and PROC GCHART to produce nine population pyramids;
%macro pyramid;
%do year = 1921 %to 2021 %by  10;

data _null_;
set c1921_2021 end=last;
where year eq &year and age eq 12;
tpop + (abs(pop) * 1000);
if last then call symput('pop',put(tpop,comma12.));
run;

title1 h=4 f='HelveticaBold' c=blue "CANADIAN POPULATION &YEAR - %left(%bquote(&pop))";
title2 h=4 ' ';
proc gchart data=c1921_2021;
where year eq &year and age ne 12;
hbar age / 
discrete
sumvar = pop
subgroup = gender
noframe
nostats
space=0
maxis=axis1
raxis=axis2
coutline=blue
annotate=age_labels
nolegend
;
format pop posval.; 
run;
quit;

%end;
%mend;

%pyramid;

*** add records to the end of the HTML file;
data _null_;
   file _webout mod;
   input;
   put _infile_;
   datalines;
   ">
   </applet>
   </body>
   </html>
   ;
run;

*** deassign the _WEBOUT filename;
filename _webout;
